logo       


CVS: phpwiki/lib WikiDB.php,1.84,1.85 editpage.php,1.74,1.75 stdlib.php,1.2: msg#00039

Subject: CVS: phpwiki/lib WikiDB.php,1.84,1.85 editpage.php,1.74,1.75 stdlib.php,1.202,1.203
Update of /cvsroot/phpwiki/phpwiki/lib
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv31650

Modified Files:
        WikiDB.php editpage.php stdlib.php 
Log Message:
just some comments


Index: WikiDB.php
===================================================================
RCS file: /cvsroot/phpwiki/phpwiki/lib/WikiDB.php,v
retrieving revision 1.84
retrieving revision 1.85
diff -u -2 -b -p -d -r1.84 -r1.85
--- WikiDB.php  14 Sep 2004 10:34:30 -0000      1.84
+++ WikiDB.php  16 Sep 2004 08:00:51 -0000      1.85
@@ -22,5 +22,7 @@ define('WIKIDB_FORCE_CREATE', -1);
 
 // FIXME:  used for debugging only.  Comment out if cache does not work
-define('USECACHE', 1);
+// or RAM is too low.
+if (!defined('USECACHE'))
+    define('USECACHE', 1);
 
 /** 
@@ -1917,4 +1919,7 @@ class WikiDB_cache 
 
 // $Log$
+// Revision 1.85  2004/09/16 08:00:51  rurban
+// just some comments
+//
 // Revision 1.84  2004/09/14 10:34:30  rurban
 // fix TransformedText call to use refs

Index: stdlib.php
===================================================================
RCS file: /cvsroot/phpwiki/phpwiki/lib/stdlib.php,v
retrieving revision 1.202
retrieving revision 1.203
diff -u -2 -b -p -d -r1.202 -r1.203
--- stdlib.php  14 Sep 2004 10:11:44 -0000      1.202
+++ stdlib.php  16 Sep 2004 08:00:52 -0000      1.203
@@ -1631,4 +1631,8 @@ function url_get_contents( $uri ) {
 }
 
+/**
+ * Generate consecutively named strings:
+ *   Name, Name2, Name3, ...
+ */
 function GenerateId($name) {
     static $ids = array();
@@ -1642,7 +1646,8 @@ function GenerateId($name) {
 }
 
-
-
 // $Log$
+// Revision 1.203  2004/09/16 08:00:52  rurban
+// just some comments
+//
 // Revision 1.202  2004/09/14 10:11:44  rurban
 // start 2nd Id with ...Plugin2



-------------------------------------------------------
This SF.Net email is sponsored by: YOU BE THE JUDGE. Be one of 170
Project Admins to receive an Apple iPod Mini FREE for your judgement on
who ports your project to Linux PPC the best. Sponsored by IBM.
Deadline: Sept. 24. Go here: http://sf.net/ppc_contest.php


Ruby Jobs
Java Jobs
Jobs in California
more...
what
job title, keywords
where
city, state, zip
jobs by job search
Search:
Java, servers, webhosting, windows, cisco ...
more...
<Prev in Thread] Current Thread [Next in Thread>
Google Custom Search

Recently Viewed:
encryption.gpg....    ietf.rfc822/199...    freebsd.devel.i...    lang.haskell.li...    mail.squirrelma...    web.zope.plone....    yellowdog.gener...    text.xml.xalan....    recreation.phot...    kde.devel.educa...    hardware.bus.ca...    printing.ghosts...    voip.peering/20...    assembly/2006-0...    org.user-groups...    culture.interne...    network.i2p/200...    boot-loaders.ya...    xfree86.render/...    qnx.openqnx.dev...    jakarta.velocit...    user-groups.pal...   
Home | blog view | USPTO Patent Archive | advertise | OSDir is an inevitable website. super tiny logo

Free Magazines

Cisco News
Receive a free quarterly e-newsletter with exclusive articles on how Cisco IT uses its own products and solutions to enable the business.
subscribe

Systems Management News, the newspaper for IT systems administration and data center managers! Each issue of Systems Management News is chock-full of news and analysis to help you understand what's happening in your field.
subscribe

The Enterprise Newsweekly eWeek is the essential technology information source for builders of e-business.
subscribe

Oracle Magazine Oracle Magazine contains technology strategy articles, sample code, tips, Oracle and partner news, how to articles for developers and DBAs, and more. Oracle (NASDAQ: ORCL) is the world's largest enterprise software company.
subscribe

Total Telecom Total Telecom is "The Economist of the communications industry".
subscribe
Index: editpage.php
===================================================================
RCS file: /cvsroot/phpwiki/phpwiki/lib/editpage.php,v
retrieving revision 1.74
retrieving revision 1.75
diff -u -2 -b -p -d -r1.74 -r1.75
--- editpage.php        3 Jul 2004 07:36:28 -0000       1.74
+++ editpage.php        16 Sep 2004 08:00:52 -0000      1.75
@@ -4,5 +4,5 @@ rcs_id('$Id$');
 require_once('lib/Template.php');
 
 // USE_HTMLAREA - WYSIWYG HTML Editor
 // Not yet enabled, since we cannot convert HTML to Wiki Markup yet.
 // (See HtmlParser.php for the ongoing efforts)
@@ -763,4 +763,7 @@ extends PageEditor
 /**
  $Log$
+ Revision 1.75  2004/09/16 08:00:52  rurban
+ just some comments
+
  Revision 1.74  2004/07/03 07:36:28  rurban
  do not get unneccessary content
@@ -4,5 +4,5 @@ rcs_id('$Id$');
 require_once('lib/Template.php');
 
-// USE_HTMLAREA - WYSIWYG HTML Editor
+// USE_HTMLAREA - Support for some WYSIWYG HTML Editor
 // Not yet enabled, since we cannot convert HTML to Wiki Markup yet.
 // (See HtmlParser.php for the ongoing efforts)
